@@ -66,10 +66,12 @@ class AgentLifeCycle:
     _docker_images["cgs_diagnostics_streamer_api"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_api:latest"
     _docker_images["colab_master"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/ros:master"
     _docker_images["colab_description"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/ros:colab-desc"
-    _docker_images["cgs_mission_sys"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/mission_system:dev"
+    _docker_images["cgs_mission_sys"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/mission_system:latest"
     _docker_images["orbitty"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/orbitty:latest"
     _docker_images["cgs_bagger_server"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_rosbagger:latest"
     _docker_images["health_aggregator"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/health_aggregator:dev"
+    _docker_images["smartplus_sound"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/smartplus_sound_server:latest"
+    _docker_images["map_manager"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/map_manager:latest"
 
     def configure_containers(object, cfg):
         """
@@ -221,7 +223,10 @@ class AgentLifeCycle:
 
         # Based on args.list to get image(s)
         for container_name in args.list:
-            image_set.add(object._docker_images[container_name])
+            try:
+                image_set.add(object._docker_images[container_name])
+            except KeyError as exp:
+                print(bcolors.WARNING + "Container: " + container_name + " not found. Skipping." + bcolors.ENDC)
 
         success_flag = True
         docker_client = permission_safe_docker_call(docker.from_env)
@@ -325,7 +330,7 @@ class AgentLifeCycle:
                 result = object._restart_protocol(args)
         else:
             result = success_flag
-            print("Error: The following image(s) shown below cannot be found")
+            print(bcolors.FAIL + "Error: The following image(s) shown below cannot be found" + bcolors.ENDC)
             print(*missing_images, sep = "\n")
         return result
 
@@ -412,6 +417,8 @@ class AgentLifeCycle:
             args.list = object._docker_container_names
 
         object._agent_run_options = {}
+
+        # diagnostics agent/API run config
         object._agent_run_options["cgs_diagnostics_agent"] = {"command": "rosrun error_resolution_diagnoser error_resolution_diagnoser", "volumes": {
             args.config.config_path + "agent/logs/": {"bind": "/root/.cognicept/agent/logs", "mode": "rw"}}, "network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_ecs_api"] = {
@@ -419,6 +426,7 @@ class AgentLifeCycle:
         object._agent_run_options["cgs_diagnostics_streamer_api"] = {"command": "/src/streamer_endpoint.py", "volumes": {
             args.config.config_path + "agent/logs/bunched_logs": {"bind": "/root/.cognicept/agent/logs/bunched_logs", "mode": "rw"}}, "network_mode": "host"}
 
+        # health aggregator run config
         object._agent_run_options["health_aggregator"] = {"command": "roslaunch health_monitoring_aggregator aggregator.launch --wait", "volumes": {
             args.config.config_path + "health_config.yaml": {"bind": "/home/aggregator_ws/src/health_monitoring_aggregator/config.yml", "mode": "rw"}}, "network_mode": "host"}
 
@@ -432,18 +440,32 @@ class AgentLifeCycle:
             object._agent_run_options["remote_intervention_agent"]["devices"] = ["/dev/snd"]
         object._agent_run_options["kriya"] = object._agent_run_options["remote_intervention_agent"]
         object._agent_run_options["kriya_watchdog"] = {
-            "command": "python3 /home/watchdog.py", "network_mode": "host", "volumes": {
+            "command": "python3 /home/watchdog.py", "volumes": {
                 args.config.config_path + "kriya_logs/": {"bind": "/root/logs/", "mode": "rw"},
                 "/var/run/docker.sock/": {"bind": "/var/run/docker.sock/", "mode": "rw"}}}
 
+        # kopilot run config
         object._agent_run_options["kopilot"] = {"command": "", "network_mode": "host", "volumes": {
             args.config.config_path + "kockpit.yaml": {"bind": "/root/config/kockpit.yaml", "mode": "rw"}}}
 
-        object._agent_run_options["rosbridge"] = {
-            "command": "roslaunch rosbridge_server rosbridge_websocket.launch", "network_mode": "host"}
-        object._agent_run_options["test"] = {"command": "bash"}
+        # ROSBagger run config
         object._agent_run_options["cgs_bagger_server"] = {"command": "rosrun cognicept_rosbagger bagger_action_server.py", "volumes": {
             args.config.config_path + "bags/": {"bind": "/root/.cognicept/bags", "mode": "rw"}}, "network_mode": "host"}
+        
+        # Smart+ Sound Server run config
+        object._agent_run_options["smartplus_sound"] = {"volumes": {
+            args.config.config_path + "sounds/": {"bind": "/root/.cognicept/sounds", "mode": "rw"},
+            args.config.config_path + "tts_configuration.yaml": {"bind": "/home/smartplus_sound_server_ws/src/tts/config/sample_configuration.yaml", "mode": "rw"}},
+            "network_mode": "host", "devices": ["/dev/snd"]}
+
+        # Map Manager run config
+        object._agent_run_options["map_manager"] = {"volumes": {
+            args.config.config_path + "slamware_maps/": {"bind": "/root/.cognicept/slamware_maps", "mode": "rw"},
+            args.config.config_path + "map_server_maps/": {"bind": "/root/.cognicept/map_server_maps", "mode": "rw"},
+            args.config.config_path + "building_info.json": {"bind": "/home/map_manager_ws/src/map_manager/config/sample_building_info.json", "mode": "rw"}},
+            "network_mode": "host"}        
+        
+        # Default other config
         object._agent_run_options["other"] = {
             "command": "", "network_mode": "host"}
         permission_docker_call_result = permission_safe_docker_call(
@@ -474,6 +496,16 @@ class AgentLifeCycle:
                 options["name"] = container_name
                 options["detach"] = True
                 options["environment"] = args.config.config
+                try:
+                    if container_name == "smartplus_sound":
+                        options["environment"]["ALSA_CARD"] = options["environment"]["SOUND_DEV_OUT"]
+                    elif container_name == "remote_intervention_agent":
+                        options["environment"]["ALSA_CARD"] = options["environment"]["SOUND_DEV_IN"]
+                except KeyError as exp:
+                    print(bcolors.WARNING + 'Missing sound device configuration in runtime.' +
+                        ' Might result in sound features not working as expected.' +
+                        ' Explicitly define `SOUND_DEV_IN` and `SOUND_DEV_OUT` variables.' + 
+                        bcolors.ENDC)
                 options["restart_policy"] = {"Name": "unless-stopped"}
                 options["tty"] = True
                 options["log_config"] = LogConfig(
@@ -492,7 +524,8 @@ class AgentLifeCycle:
                 print(bcolors.WARNING + "IMAGE NOT FOUND" +
                       bcolors.ENDC + " (run `cognicept update`)")
                 success_flag = False
-            except docker.errors.APIError:
+            except docker.errors.APIError as exp:
+                print(exp)
                 print(bcolors.FAIL + "DOCKER ERROR" + bcolors.ENDC)
                 success_flag = False
         return success_flag
